Ducker (ducker v0.5.0)

Copy Markdown View Source

Documentation for Ducker.

Summary

Functions

Create data tests from YAML string

Executes all SQL files (.sql) in the given directory.

Executes the specified SQL file.

Initializes a Ducker struct with a connection and work directory.

Resets the data test result in the database.

Types

t()

@opaque t()

Functions

data_test_from_string(str)

Create data tests from YAML string

execute_query_from_dir(ducker, dir, opts \\ [])

Executes all SQL files (.sql) in the given directory.

Options

  • :assigns - A list of key-value pairs to be used as bindings in SQL files.

execute_query_from_file(ducker, file, opts \\ [])

Executes the specified SQL file.

Options

  • :assigns - A list of key-value pairs to be used as bindings in SQL files.

execute_test_from_dir(ducker, dir, opts \\ [])

execute_test_from_file(ducker, file)

new!(conn, work_dir)

Initializes a Ducker struct with a connection and work directory.

reset_test_result!(ducker)

Resets the data test result in the database.