Documentation for Ducker.
Summary
Functions
Create data tests from YAML string
Executes all SQL files (.sql) in the given directory.
Executes the specified SQL file.
Initializes a Ducker struct with a connection and work directory.
Resets the data test result in the database.
Types
Functions
Create data tests from YAML string
Executes all SQL files (.sql) in the given directory.
Options
:assigns- A list of key-value pairs to be used as bindings in SQL files.
Executes the specified SQL file.
Options
:assigns- A list of key-value pairs to be used as bindings in SQL files.
Initializes a Ducker struct with a connection and work directory.
Resets the data test result in the database.